Convert stable text to a standalone snippet
character vector of table text.
used to build intermediate and output file names.
directory for building the pdf file.
the font to use; alternative values include roboto and
utopia; passed to st_to_standalone().
pass pdflatex when building a pdf file or latex when
building png.
the page width (in inches) when building with pdflatex;
passed to st_to_standalone(); see details.
passed as an option to standalone latex output type; see
details.
Deprecated. This argument no longer has an effect. Underneath,
latexmk is used to run the underlying command (e.g., pdflatex) as many
times as required.
numeric version number for the longtable package; newer versions have an issue that will break this code for longtables; so we are requiring an older version at this point.